
# Type: case to thing association_subject




URI: [biolink:case_to_thing_association_subject](https://w3id.org/biolink/vocab/case_to_thing_association_subject)


## Domain and Range

[CaseToThingAssociation](CaseToThingAssociation.md) ->  <sub>REQ</sub> [Case](Case.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [CaseToThingAssociation](CaseToThingAssociation.md)
